Heuristic

Trait Heuristic 

pub trait Heuristic: Send + Sync {
    // Required methods
    fn name(&self) -> &str;
    fn estimate(&self, task: &Task, state: &State) -> HValue;

    // Provided method
    fn preferred_ops(&self, _task: &Task, _state: &State) -> &[OpId] { ... }
}
A heuristic function for estimating the cost to reach the goal.

Implementors must be Send + Sync for use in multi-threaded contexts.

Required Methods

fn name(&self) -> &str

A human-readable name for this heuristic.

fn estimate(&self, task: &Task, state: &State) -> HValue

Estimate the cost from state to the goal in task.

Provided Methods

fn preferred_ops(&self, _task: &Task, _state: &State) -> &[OpId]

Return preferred operators for the current state (used by some planners). The default implementation returns an empty slice.

Implementors